pecos.slr.util
==============

.. automodule:: pecos.slr.util

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      list2str
      rm_white_space
      str2list
   
   

   
   
   

   
   
   



